@@ -191,7 +191,7 @@ class PipelineRun:
             associatedJobUids = []
         payload = self._convert_span_to_dict(create_span, associatedJobUids)
         res = self.client.create_span(self.id, payload)
-        span_context = SpanContext(client=self.client, span=res, context_data= context_data)
+        span_context = SpanContext(client=self.client, span=res, context_data= context_data, new_span = True)
         return span_context
 
     def get_span(self, span_uid: str):
@@ -205,6 +205,16 @@ class PipelineRun:
         span_context = SpanContext(client=self.client, span= span)
         return span_context
 
+    def get_root_span(self):
+        """
+            Description:
+                Get root span of the pipeline run
+        :return: SpanContext instance of the root span
+        """
+        span = self.client.get_root_span( pipeline_run_id=self.id)
+        span_context = SpanContext(client=self.client, span=span)
+        return span_context
+
 class Pipeline:
     def __init__(self, uid: str,
                  name: str,
