@@ -390,6 +390,18 @@ class TorchHttpClient(TorchClientInterFace, ABC):
         response['span']['client'] = self
         return Span(**response['span'])
 
+    def get_root_span(self, pipeline_run_id: int):
+        """
+            Description:
+                Get root span of the pipeline run
+        :param pipeline_run_id: pipeline run id
+        :return: SpanContext instance of the root span
+        """
+        url = f'{self._pipeline_api_base}/pipelines/runs/{pipeline_run_id}/spans/root-span'
+        response = self._get(url)
+        response['span']['client'] = self
+        return Span(**response['span'])
+
     # convert span object to dict type
     def convert_span_event_to_dict(self, span_event: CreateSpanEvent):
         """
@@ -1135,17 +1147,23 @@ class TorchHttpClient(TorchClientInterFace, ABC):
         )
         return RuleCancelResponse(**response['result'])
 
-    def execute_dq_rule(self, rule_id):
+    def execute_dq_rule(self, rule_id, incremental=False):
+        payload_temp = {"executionType": "FULL"}
+        if incremental:
+            payload_temp = {"executionType": "INCREMENTAL"}
         response = self._post(
             url=f'{self._catalog_api_base}/rules/data-quality/{rule_id}/executions',
-            payload={"executionType": "FULL"}
-        )
+            payload=payload_temp
+            )
         return RuleExecution(**response['execution'])
 
-    def execute_reconciliation_rule(self, rule_id):
+    def execute_reconciliation_rule(self, rule_id, incremental=False):
+        payload_temp = {"executionType": "FULL"}
+        if incremental:
+            payload_temp = {"executionType": "INCREMENTAL"}
         response = self._post(
             url=f'{self._catalog_api_base}/rules/reconciliation/{rule_id}/executions',
-            payload={}
+            payload=payload_temp
         )
         return RuleExecution(**response['execution'])
 
